/*
 * Router default NVRAM values
 *
 * Copyright 2007, Broadcom Corporation
 * All Rights Reserved.
 * 
 * THIS SOFTWARE IS OFFERED "AS IS", AND BROADCOM GRANTS NO WARRANTIES OF ANY
 * KIND, EXPRESS OR IMPLIED, BY STATUTE, COMMUNICATION OR OTHERWISE. BROADCOM
 * SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
 *
 * $Id$
 */

#include <epivers.h>
#include <typedefs.h>
#include <string.h>
#include <bcmnvram.h>
#include <wlioctl.h>
#include <stdio.h>
#include <ezc.h>
#include <bcmconfig.h>
/*USR*/
#include "projects.h"

#define XSTR(s) STR(s)
#define STR(s) #s

struct nvram_tuple router_defaults[] = {
	/* OS parameters */
	{ "os_name", "", 0 },			/* OS name string */
	{ "os_version", EPI_VERSION_STR, 0 },	/* OS revision */
	{ "os_date", __DATE__, 0 },		/* OS date */

	/* Version */
	{ "nvram_version", NVRAM_SOFTWARE_VERSION, 0 },

	/* Miscellaneous parameters */
	{ "log_ipaddr", "", 0 },		/* syslog recipient */
	{ "timer_interval", "3600", 0 },	/* Timer interval in seconds */
	{ "ntp_server", "192.43.244.18 81.168.107.97 128.252.19.1", 0 },		/* NTP server */
	{ "time_zone", "PST8PDT", 0 },		/* Time zone (GNU TZ format) */
	{ "upnp_enable", "0", 0 },		
	#ifdef NPHY
	{ "ezc_enable", "1", 0 },		/* Enable EZConfig updates */
	{ "ezc_version", EZC_VERSION_STR, 0 },	/* EZConfig version */
	#endif /* NPHY */
	{ "is_default", "1", 0 },		/* is it default setting: 1:yes 0:no*/
	{ "os_server", "", 0 },			/* URL for getting upgrades */
	{ "console_loglevel", "1", 0 },		/* Kernel panics only */

	/* LAN H/W parameters */
	{ "lan_ifname", "", 0 },		/* LAN interface name */
	{ "lan_ifnames", "", 0 },		/* Enslaved LAN interfaces */
	{ "lan_hwnames", "", 0 },		/* LAN driver names (e.g. et0) */
	{ "lan_hwaddr", "", 0 },		/* LAN interface MAC address */

	/* LAN TCP/IP parameters */
	{ "lan_netmask", "255.255.255.0", 0 },	/* LAN netmask */
	{ "lan_wins", "", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "lan_domain", "", 0 },		/* LAN domain name */
	{ "lan_route", "", 0 },			/* Static routes (ipaddr:netmask:gateway:metric:ifname ...) */
	{ "ure_disable", "1", 0 },		/* sets APSTA for radio and puts wireless interfaces in correct lan */
#ifdef CLIENT	
	{ "lan_lease", "6", 0 },		/* LAN lease time in seconds */
#else
	{ "lan_lease", "3600", 0},
#endif
	
#ifdef CLIENT
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.201", 0 },	/* LAN IP address */
	{ "lan_gateway", "192.168.1.201", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.1.202", 0 },	/* First assignable DHCP address */
	{ "dhcp_end", "192.168.1.202", 0 },	/* Last assignable DHCP address */
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "wet", 0 },		/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "", 0 },			/* Service set ID (network name) */
	{ "wl_sta_retry_time", "5", 0 }, 	/* Seconds between association attempts */
	{ "wl_afterburner", "off", 0 },		/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "frameburst", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.201", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "5", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif 

	/* Guest H/W parameters */
	{ "lan1_ifname", "", 0 },		/* LAN interface name */
	{ "lan1_ifnames", "", 0 },		/* Enslaved LAN interfaces */
	{ "lan1_hwnames", "", 0 },		/* LAN driver names (e.g. et0) */
	{ "lan1_hwaddr", "", 0 },		/* LAN interface MAC address */

	/* Guest TCP/IP parameters */
	{ "lan1_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan1_ipaddr", "192.168.2.1", 0 },	/* LAN IP address */
	{ "lan1_netmask", "255.255.255.0", 0 },	/* LAN netmask */
	{ "lan1_gateway", "192.168.2.1", 0 },	/* LAN gateway */
	{ "lan1_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "lan1_wins", "", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "lan1_domain", "", 0 },		/* LAN domain name */
	{ "lan1_lease", "86400", 0 },		/* LAN lease time in seconds */
	{ "lan1_stp", "1", 0 },			/* LAN spanning tree protocol */
	{ "lan1_route", "", 0 },			/* Static routes
						 * (ipaddr:netmask:gateway:metric:ifname ...)
						 */

#ifdef REPEATER
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5441", 0 },
	{ "wl_afterburner", "auto", 0 },	/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "0", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "4", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif
#ifdef AP
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5451", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "auto", 0 },	/* AfterBurner */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "wl_multicast", "on", 0 },		/* USR - enable/disable multicast (on/off) */
	{ "COMPAT_ID", "2", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif
#ifdef ROUTER
	{ "router_disable", "0", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "log_level", "0", 0 },		/* Bitmask 0:off 1:denied 2:accepted */
	{ "stats_server", "", 0 },		/* URL for posting stats */
	/* Big switches */
	{ "fw_disable", "0", 0 },		/* Disable firewall (allow new connections from the WAN) */
	{ "lan_ipaddr", "192.168.2.1", 0 },
	{ "lan_gateway", "192.168.2.1", 0 },	/* LAN gateway */
	{ "lan_stp", "1", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.2.2", 0 },
	{ "dhcp_end", "192.168.2.31", 0},
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "lan_dns", "192.168.2.1", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5461", 0 },
	{ "wl_afterburner", "auto", 0 },		/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "COMPAT_ID", "1", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "sysdbg", "off", 0 },			/* syslog firewall enabled/disabled: on/off */
#endif
#ifdef GAMING
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "wet", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5431", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "auto", 0 },		/* AfterBurner */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_sta_retry_time", "5", 0 }, /* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "6", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif
#ifdef BRIDGE
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "wet", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5432", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "auto", 0 },		/* AfterBurner */
	{ "wl_lazywds", "0", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_sta_retry_time", "5", 0 }, /* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "7", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif
#ifdef ROUTERN
	{ "router_disable", "0", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "log_level", "0", 0 },		/* Bitmask 0:off 1:denied 2:accepted */
	{ "stats_server", "", 0 },		/* URL for posting stats */
	/* Big switches */
	{ "fw_disable", "0", 0 },		/* Disable firewall (allow new connections from the WAN) */
	{ "lan_ipaddr", "192.168.2.1", 0 },
	{ "lan_gateway", "192.168.2.1", 0 },	/* LAN gateway */
	{ "lan_stp", "1", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.2.2", 0 },
	{ "dhcp_end", "192.168.2.31", 0},
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "lan_dns", "192.168.2.1", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5464", 0 },
	{ "wl_afterburner", "off", 0 },	/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "frameburst", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "COMPAT_ID", "8", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "ddns_list0", "", 0 },		/* format for dyn dns list: "hostname:username:password:service:active "(space after active, active values on/off) */
	{ "sysdbg", "off", 0 },			/* syslog firewall enabled/disabled: on/off */
#endif
#ifdef APN
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5454", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "off", 0 },	/* AfterBurner */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "frameburst", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "wl_multicast", "on", 0 },		/* USR - enable/disable multicast (on/off) */
	{ "COMPAT_ID", "9", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "extender", "0", 0 },			/* value of 1 if the AP is used as range extender */
	{ "scanvar", "ap", 0 },			/* value of 1 if the AP is used as range extender */
#endif
#ifdef __CONFIG_NAT__
	/* WAN H/W parameters */
	{ "wan_ifname", "", 0 },		/* WAN interface name */
	{ "wan_ifnames", "", 0 },		/* WAN interface names */
	{ "wan_hwname", "", 0 },		/* WAN driver name (e.g. et1) */
	{ "wan_hwaddr", "", 0 },		/* WAN interface MAC address */

	/* WAN TCP/IP parameters */
	{ "wan_proto", "dhcp", 0 },		/* [static|dhcp|pppoe|disabled] */
	{ "wan_ipaddr", "0.0.0.0", 0 },		/* WAN IP address */
	{ "wan_netmask", "0.0.0.0", 0 },	/* WAN netmask */
	{ "wan_gateway", "0.0.0.0", 0 },	/* WAN gateway */
	{ "wan_dns", "", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "wan_wins", "", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "wan_hostname", "", 0 },		/* WAN hostname */
	{ "wan_domain", "", 0 },		/* WAN domain name */
	{ "wan_lease", "86400", 0 },		/* WAN lease time in seconds */

	/* PPPoE parameters */
	{ "wan_pppoe_ifname", "", 0 },		/* PPPoE enslaved interface */
	{ "wan_pppoe_username", "", 0 },	/* PPP username */
	{ "wan_pppoe_passwd", "", 0 },		/* PPP password */
	{ "wan_pppoe_idletime", "60", 0 },	/* Dial on demand max idle time (seconds) */
	{ "wan_pppoe_keepalive", "1", 0 },	/* Restore link automatically */
	{ "wan_pppoe_demand", "0", 0 },		/* Dial on demand */
	{ "wan_pppoe_mru", "1492", 0 },		/* Negotiate MRU to this value */
	{ "wan_pppoe_mtu", "1492", 0 },		/* Negotiate MTU to the smaller of this value or the peer MRU */
	{ "wan_pppoe_service", "", 0 },		/* PPPoE service name */
	{ "wan_pppoe_ac", "", 0 },		/* PPPoE access concentrator name */
	/* PPTP parameters */
	{ "wan_pptp_activated", "0", 0 },	/* PPTP activation status */
	{ "wan_pptp_ifname", "", 0 },		/* PPTP enslaved interface */
	{ "wan_pptp_server", "", 0 },		/* PPTP server */
	{ "wan_pptp_username", "", 0 },		/* PPP username */
	{ "wan_pptp_passwd", "", 0 },		/* PPP password */
	{ "wan_pptp_auth", "0 1 1 1", 0 },	/* authentication required: 1 = PAP; 2 = CHAP; 4 = MSCHAP; 8 = MSCHAP-v2 */
	{ "wan_pptp_ipaddr", "0.0.0.0", 0 },	/* PPTP ipaddress*/
	{ "wan_pptp_netmask", "0.0.0.0", 0 },	/* PPTP netmask */
	{ "wan_pptp_gateway", "0.0.0.0", 0 },	/* PPTP gateway */
	{ "wan_pptp_dns", "", 0 },		/* PPTP gateway */
	{ "wan_pptp_mru", "1460", 0 },		/* Negotiate MRU to this value */
	{ "wan_pptp_mtu", "1460", 0 },		/* Negotiate MTU to the smaller of this value or the peer MRU */
	//{ "wan_pptp_idletime", "60", 0 },	/* Dial on demand max idle time (seconds) */
	//{ "wan_pptp_demand", "0", 0 },	/* Dial on demand */
	//{ "wan_pptp_mppe", "0 0", 0 },	/* MPPE Encryption required: 0 = none; 1 = 40 bits; 2 = 128 bits can be combined */
	//{ "wan_pptp_mppe_mode", "0", 0 },	/* MPPE mode required: 0 = stateless; 1 = statefull */
	//{ "wan_pptp_inbound", "1", 0 },
	//{ "wan_pptp_keepalive", "1", 0 },	/* Restore link automatically */
	/* Misc WAN parameters */
	{ "wan_desc", "", 0 },			/* WAN connection description */
	{ "wan_route", "", 0 },			/* Static routes (ipaddr:netmask:gateway:metric:ifname ...) */
	{ "wan_primary", "0", 0 },		/* Primary wan connection */

	{ "wan_unit", "0", 0 },			/* Last configured connection */

	/* Filters */
	{ "filter_maclist", "", 0 },		/* xx:xx:xx:xx:xx:xx ... */
	{ "filter_macmode", "deny", 0 },	/* "allow" only, "deny" only, or "disabled" (allow all) */
#ifdef ROUTERN	
	{ "filter_client0", "192.168.2.100-192.168.2.110:1-65535,tcp,1-5,79201-61200,off", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
	{ "filter_client1", "192.168.2.100-192.168.2.110:1-65535,tcp,6-0,2-28800,off", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
#else
	{ "filter_client0", "", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
	{ "filter_client1", "", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
#endif
	/* Port forwards */
	{ "dmz_ipaddr", "", 0 },		/* x.x.x.x (equivalent to 0-60999>dmz_ipaddr:0-60999) */
#ifdef ROUTERN	
	{ "forward_port0", "80-80>192.168.2.120:80-80,tcp,off", 0 },		/* wan_port0-wan_port1>lan_ipaddr:lan_port0-lan_port1[:,]proto[:,]enable[:,]desc */
	{ "autofw_port0", "tcp:1-65535,tcp:10070-10080>10070-10080,off", 0 },	/* out_proto:out_port,in_proto:in_port0-in_port1>to_port0-to_port1,enable,desc */
	{ "autofw_port1", "udp:1-65535,udp:10070-10070>10070-10070,off", 0 },	/* out_proto:out_port,in_proto:in_port0-in_port1>to_port0-to_port1,enable,desc */
#else
	{ "forward_port0", "", 0 },	/* wan_port0-wan_port1>lan_ipaddr:lan_port0-lan_port1[:,]proto[:,]enable[:,]desc */
	{ "autofw_port0", "", 0 },	/* out_proto:out_port,in_proto:in_port0-in_port1>to_port0-to_port1,enable,desc */
#endif	
	/* DHCP server parameters */
	{ "dhcp_domain", "wan", 0 },		/* Use WAN domain name first if available (wan|lan) */
	{ "dhcp_wins", "wan", 0 },		/* Use WAN WINS first if available (wan|lan) */
	{ "dhcp_ipaddr", "", 0 },		/* dhcp client list */
	{ "ipp_port", "1631", 0 },		/* print server port */
	{ "wan_ipp", "0", 0 },			/* remote printing: 0 = disabled, 1 = enabled */
#endif	/* __CONFIG_NAT__ */
	/* Web server parameters */
#ifdef CLIENT
	{ "http_username", "admin", 0 },	/* Username */
	{ "http_passwd", "admin", 0 },		/* Password */
#else
	{ "http_username", "", 0 },		/* Username */
	{ "http_passwd", "", 0 },		/* Password */
#endif
	{ "http_wanport", "", 0 },		/* WAN port to listen on */
	{ "http_lanport", "80", 0 },		/* LAN port to listen on */

	/* Wireless parameters */
	{ "wl_ifname", "", 0 },			/* Interface name */
	{ "wl_hwaddr", "", 0 },			/* MAC address */
	{ "wl_phytype", "g", 0 },		/* Current wireless band ("a" (5 GHz), "b" (2.4 GHz), or "g" (2.4 GHz)) */
	{ "wl_corerev", "", 0 },		/* Current core revision */
	{ "wl_phytypes", "", 0 },		/* List of supported wireless bands (e.g. "ga") */
	{ "wl_radioids", "", 0 },		/* List of radio IDs */
	{ "wl_bss_enabled", "1", 0 },		/* Service set ID (network name) */
	//{ "wl_country", "", 0 },		/* Country (default obtained from driver) */
	//{ "wl_country_code", "", 0 },		/* Country (default obtained from driver) */
	{ "wl_radio", "1", 0 },			/* Enable (1) or disable (0) radio */
	{ "wl_closed", "0", 0 },		/* Closed (hidden) network */
	{ "wl_ap_isolate", "0", 0 },            /* AP isolate mode */
	{ "wl_wds", "", 0 },			/* xx:xx:xx:xx:xx:xx ... */
	{ "wl_wds_timeout", "1", 0 },		/* WDS link detection interval defualt 1 sec */
	{ "wl_wep", "disabled", 0 },		/* WEP data encryption (enabled|disabled) */
	{ "wl_auth", "0", 0 },			/* Shared key authentication optional (0) or required (1) */
	{ "wl_key", "1", 0 },			/* Current WEP key */
	{ "wl_key1", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_key2", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_key3", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_key4", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_maclist", "", 0 },		/* xx:xx:xx:xx:xx:xx ... */
	{ "wl_macmode", "disabled", 0 },	/* "allow" only, "deny" only, or "disabled" (allow all) */
#ifdef NPHY	
	{ "wl_channel", "0", 0 },		/* Channel number - Automatic*/
#else
	{ "wl_channel", "11", 0 },		/* Channel number */
#endif
	{ "wl_reg_mode", "off", 0 },		/* Regulatory: 802.11H(h)/802.11D(d)/off(off) */
	{ "wl_dfs_preism", "60", 0 },		/* 802.11H pre network CAC time */
	{ "wl_dfs_postism", "60", 0 },		/* 802.11H In Service Monitoring CAC time */
	/* Radar parameters by phy for 20 and 40 MHz channels respectively 
	 * (npulses ncontig min_pw max_pw thresh0 thresh1 blank fmdemodcfg npulses_lp min_pw_lp
	 *  max_pw_lp min_fm_lp max_deltat_lp min_deltat max_deltat
	 */
	{ "wl_radarargs_11a",
	"5 4 4 100 0x2b0 0x2f0 0x0 0x0 8 500 4000 10 240000000 1000 3000000", 0 },
	{ "wl_radarargs_11n",
	"5 4 3 100 0x6b0 0x6f0 0x2c40 0x7f09 6 300 1200 25 200000000 1000 3000000", 0},
	{ "wl_radarargs40_11n",
	"5 4 4 100 0x6b0 0x6d9 0x2c40 0x7f07 12 195 2000 25 400000000 1000 6000000", 0 },
	{ "wl_rate", "0", 0 },			/* Rate (bps, 0 for auto) */
	{ "wl_rateset", "default", 0 },		/* "default" or "all" or "12" */
	{ "wl_frag", "2346", 0 },		/* Fragmentation threshold */
	{ "wl_rts", "2347", 0 },		/* RTS threshold */
	{ "wl_dtim", "1", 0 },			/* DTIM period */
	{ "wl_bcn", "100", 0 },			/* Beacon interval */
	{ "wl_plcphdr", "long", 0 },		/* 802.11b PLCP preamble type */
	{ "wl_gmode", XSTR(GMODE_AUTO), 0 },	/* 54g mode */
	{ "wl_gmode_protection", "auto", 0 },	/* 802.11g RTS/CTS protection (off|auto) */
	{ "wl_wme", "off", 0 },			/* WME mode (off|on|auto) */
	{ "wl_wme_bss_disable", "0", 0 },	/* WME BSS disable advertising (off|on) */
	{ "wl_antdiv", "-1", 0 },		/* Antenna Diversity (-1|0|1|3) */
	{ "wl_infra", "1", 0 },			/* Network Type (BSS/IBSS) */
#ifdef NPHY
	{ "wl_nmode", "-1", 0 },		/* 802.11n mode (-1 (auto)| 0 (off) */
	{ "wl_leddc", "0x640000", 0},		/* 100% duty cycle for LED on router */
	{ "wl_nbw_cap", "0", 0},		/* N-BW 0 - 20MHz in both bands, 1 - 40MHz in both bands, 2- 20 in 2.4 G and 40 in 5G */
	{ "wl_nctrlsb", "lower", 0},		/* N-CTRL SB */
	{ "wl_nband", "2", 0},			/* N-BAND */
	{ "wl_nmcsidx", "-1", 0},		/* MCS Index for N - rate */
	{ "wl_nmode_protection", "auto", 0 },	/* 802.11n RTS/CTS protection (off|auto) */
	{ "wl_nreqd", "0", 0},			/* Require 802.11n support */
	{ "wl_vlan_prio_mode", "off", 0},	/* VLAN Priority support */
#endif
	{ "wl_rxstreams", "0", 0},		/* 802.11n Rx Streams, 0 is invalid, WLCONF will
						 * change it to a radio appropriate default
						 */
	{ "wl_txstreams", "0", 0},		/* 802.11n Tx Streams 0, 0 is invalid, WLCONF will
						 * change it to a radio appropriate default
						 */

	/* WPA parameters */
	{ "wl_auth_mode", "none", 0 },		/* Network authentication mode (radius|none) */
	{ "wl_wpa_psk", "", 0 },		/* WPA pre-shared key */
	{ "wl_wpa_gtk_rekey", "0", 0 },		/* GTK rotation interval */
	{ "wl_crypto", "tkip", 0 },		/* WPA data encryption */
	/* USR new parameters */
#ifdef CLIENT
	{ "cbAuthEncrypt", "open", 0 },		/* USR-authentication (none|wpa12|wpa2|wpa|radius-wpa12|radius-wpa2|radius-wpa|open|shared) */
#else
	{ "cbAuthEncrypt", "none", 0 },		/* USR-authentication (none|wpa12|wpa2|wpa|radius-wpa12|radius-wpa2|radius-wpa|open|shared) */
#endif	
	{ "cbEncryption", "none", 0 },		/* USR-encryption (tkip|aes|tkip+aes|wl_wep_open|wl_wep_shared) */
	{ "connection", "keepalive", 0 },		/* USR-pppoe connection (timeout|demand|keepalive) */ 
	//{ "wl_power", "79", 0 },		/* USR-TXPWR level - old power*/
	{ "wl_power", "76", 0 },		/* USR-TXPWR level qtxpower*/
	{ "wl_net_reauth", "3600", 0 },		/* Network Re-auth/PMK caching duration */
	{ "wl_akm", "", 0 },			/* WPA akm list */

	/* SES parameters */
	{ "ses_enable", "1", 0 },		/* enable ses */
	{ "ses_event", "2", 0 },		/* initial ses event */
	{ "ses_wds_mode", "1", 0 },		/* enabled if ses cfgd */
#ifdef __CONFIG_WSCCMD__
	/* WSC parameters */
	{ "wsc_mode", "disabled", 0 },	 /* disable wsc */
	{ "wl_wsc_mode", "disabled", 0 },
	{ "wsc_config_state", "1", 0 },	/* config state unconfiged */
	{ "wsc_device_pin", "12345670", 0 },
	{ "wsc_modelname", "Broadcom", 0 },
	{ "wsc_mfstring", "Broadcom", 0 },
	{ "wsc_device_name", "BroadcomAP", 0 },
	{ "wl_wsc_reg", "enabled", 0 },
	{ "wsc_sta_pin", "0", 0 },
	{ "wsc_modelnum", "123456", 0 },
	{ "wsc_timeout_enable", "0", 0 },
	{ "wsc_addER", "0", 0 },
	{ "wsc_uuid", "0x000102030405060708090A0B0C0D0EBB", 0 },
#endif /* __CONFIG_WSCCMD__ */
	/* SES client parameters */
	{ "ses_cl_enable", "1", 0 },		/* enable ses */
	{ "ses_cl_event", "0", 0 },		/* initial ses event */

	/* WME parameters (cwmin cwmax aifsn txop_b txop_ag adm_control oldest_first) */
	/* EDCA parameters for STA */
	{ "wl_wme_sta_be", "15 1023 3 0 0 off off", 0 },	/* WME STA AC_BE parameters */
	{ "wl_wme_sta_bk", "15 1023 7 0 0 off off", 0 },	/* WME STA AC_BK parameters */
	{ "wl_wme_sta_vi", "7 15 2 6016 3008 off off", 0 },	/* WME STA AC_VI parameters */
	{ "wl_wme_sta_vo", "3 7 2 3264 1504 off off", 0 },	/* WME STA AC_VO parameters */

	/* EDCA parameters for AP */
	{ "wl_wme_ap_be", "15 63 3 0 0 off off", 0 },		/* WME AP AC_BE parameters */
	{ "wl_wme_ap_bk", "15 1023 7 0 0 off off", 0 },		/* WME AP AC_BK parameters */
	{ "wl_wme_ap_vi", "7 15 1 6016 3008 off off", 0 },	/* WME AP AC_VI parameters */
	{ "wl_wme_ap_vo", "3 7 1 3264 1504 off off", 0 },	/* WME AP AC_VO parameters */

	{ "wl_wme_no_ack", "off", 0},		/* WME No-Acknowledgment mode */
	{ "wl_wme_apsd", "on", 0},		/* WME APSD mode */

	/* Per AC Tx parameters */
	{ "wl_wme_txp_be", "7 3 4 2 0", 0 },	/* WME AC_BE Tx parameters */
	{ "wl_wme_txp_bk", "7 3 4 2 0", 0 },	/* WME AC_BK Tx parameters */
	{ "wl_wme_txp_vi", "7 3 4 2 0", 0 },	/* WME AC_VI Tx parameters */
	{ "wl_wme_txp_vo", "7 3 4 2 0", 0 },	/* WME AC_VO Tx parameters */

	{ "wl_maxassoc", "128", 0},		/* Max associations driver could support */
	{ "wl_bss_maxassoc", "128", 0},		/* Max associations driver could support */

	{ "wl_unit", "0", 0 },			/* Last configured interface */
	{ "wl_sta_retry_time", "5", 0 }, /* Seconds between association attempts */

#ifdef __CONFIG_EMF__
	/* EMF defaults */
	{ "emf_entry", "", 0 },			/* Static MFDB entry (mgrp:if) */
	{ "emf_uffp_entry", "", 0 },		/* Unreg frames forwarding ports */
	{ "emf_rtport_entry", "", 0 },		/* IGMP frames forwarding ports */
	{ "emf_enable", "0", 0 },		/* Disable EMF by default */
#endif /* __CONFIG_EMF__ */

	/* Restore defaults */
	{ "restore_defaults", "0", 0 },		/* Set to 0 to not restore defaults on boot */

	{ 0, 0, 0 }
};

/* Translates from, for example, wl0_ (or wl0.1_) to wl_. */
/* Only single digits are currently supported */

static void
fix_name(const char *name, char *fixed_name)
{
	int src_offset = 0;
	int dst_offset = 0;

	/* Translate prefix wlx_ and wlx.y_ to wl_ */
	if (name[0] == 'w' && name[1] == 'l' && (name[2] >= '0' && name[2] <= '9')) {
		src_offset = (name[3] == '.') ? 5 : 3;
		dst_offset = 2;  /* Writing in wl here */
		strcpy(fixed_name, "wl");
	}

	strcpy(&fixed_name[dst_offset], &name[src_offset]);
}


/* 
 * Find nvram param name; return pointer which should be treated as const
 * return NULL if not found.
 *
 * NOTE:  This routine special-cases the variable wl_bss_enabled.  It will
 * return the normal default value if asked for wl_ or wl0_.  But it will
 * return 0 if asked for a virtual BSS reference like wl0.1_.
 */
char *
nvram_default_get(const char *name)
{
	int idx;
	char fixed_name[NVRAM_MAX_VALUE_LEN];

	fix_name(name, fixed_name);
	if (strcmp(fixed_name, "wl_bss_enabled") == 0) {
		if (name[3] == '.' || name[4] == '.') { /* Virtual interface */
			return "0";
		}
	}

	for (idx = 0; router_defaults[idx].name != NULL; idx++) {
		if (strcmp(router_defaults[idx].name, fixed_name) == 0) {
			return router_defaults[idx].value;
		}
	}

	return NULL;
}
